/**
 * Each web page loaded in the browser has its own document object. This object serves as an entry point to the web page's content (the DOM tree, including elements such as <body> and <table> ) and provides functionality global to the document (such as obtaining the page's URL and creating new elements in the document).
 */
var document = new HTMLDocument();
/**
 * Allows web sites to register themselves as possible handlers for content of a particular MIME type.<br>Note: Web sites may only register content handlers for themselves. For security reasons, it's not possible for an extension or web site to register content handlers targeting other sites.
 * @returns {undefined} 
 * @static
 */
document.registerContentHandler = function() {};

/**
 * Gets/sets WYSYWIG editing capability of Midas. It can only be used for HTML documents.
 * @returns {String} 
 * @static
 */
document.designMode;

/**
 * Returns an XPathResult based on an XPath expression and other given parameters.
 * @syntax varxpathResult=document.evaluate(xpathExpression,contextNode,namespaceResolver,resultType,result);
 * @param {String} xpathExpression xpathExpression is a string representing the XPath to be evaluated.
 * @param {Node} contextNode contextNode specifies the context node for the query (see the [http://www.w3.org/TR/xpath XPath specification). It's common to pass document as the context node.
 * @param {String} namespaceResolver namespaceResolver is a function that will be passed any namespace prefixes and should return a string representing the namespace URI associated with that prefix. It will be used to resolve prefixes within the XPath itself, so that they can be matched with the document. null is common for HTML documents or when no namespace prefixes are used.
 * @param {Number} resultType resultType is an integer that corresponds to the type of result XPathResult to return. Use named constant properties, such as XPathResult.ANY_TYPE, of the XPathResult constructor, which correspond to integers from 0 to 9.
 * @param {XPathResult} result result is an existing XPathResult to use for the results. null is the most common and will create a new XPathResult
 * @returns {XPathResult} 
 * @static
 */
document.evaluate = function() {};

/**
 * Returns a list of the available plugins.
 * @returns {HTMLCollection} 
 * @static
 */
document.plugins;

/**
 * Returns the URI of the current document.
 * @returns {Location} 
 * @static
 */
document.location;

/**
 * This
 * @syntax target.addEventListener(type,listener[,useCapture]);<br>target.addEventListener(type,listener[,useCapture,aWantsUntrusted);//Gecko/Mozillaonly
 * @param {String} type A string representing the event type to listen for.
 * @param {Function} listener The object that receives a notification when an event of the specified type occurs. This must be an object implementing the EventListener interface, or simply a JavaScript function.
 * @param {Boolean} useCapture If true, useCapture indicates that the user wishes to initiate capture. After initiating capture, all events of the specified type will be dispatched to the registered listener before being dispatched to any EventTarget beneath it in the DOM tree. Events which are bubbling upward through the tree will not trigger a listener designated to use capture. See DOM Level 3 Events for a detailed explanation. Note that this parameter is not optional in all browser versions. If not specified, useCapture is false.
 * @param {Boolean} aWantsUntrusted If true, the event can be triggered by untrusted content. See Interaction between privileged and non-privileged pages.
 * @returns {Boolean} The return value for this method indicates whether the preference that controls Java is on or off - not whether the browser offers Java support in general.
 * @static
 */
document.addEventListener = function() {};

/**
 * Indicates whether the document is rendered in Quirks or Strict mode.
 * @returns {String} 
 * @static
 */
document.compatMode;

/**
 * Creates an XPathNSResolver which resolves namespaces with respect to the definitions in scope for a specified node.
 * @syntax nsResolver=document.createNSResolver(node);
 * @param {Node} node node is the node to be used as a context for namespace resolution.
 * @returns {XPathNSResolver} 
 * @static
 */
document.createNSResolver = function() {};

/**
 * Returns the node which is the target of the current tooltip.
 * @returns {Node|Object} 
 * @static
 */
document.tooltipNode;

/**
 * Returns a list of the embedded OBJECTS within the current document.
 * @returns {HTMLCollection} 
 * @static
 */
document.embeds;

/**
 * Returns the Content-Type from the MIME Header of the current document.
 * @returns {String} 
 * @static
 */
document.contentType;

/**
 * Returns a Boolean value indicating whether the document or any element inside the document has focus. This method can be used to determine whether the active element in a document has focus.
 * @syntax focused=document.hasFocus();
 * @returns {Boolean} false if the active element in the document has no focus; true if the active element in the document has focus.
 * @static
 */
document.hasFocus = function() {};

/**
 * Returns a reference to the window object.
 * @returns {Window} 
 * @static
 */
document.defaultView;

/**
 * Returns the node upon which a popup was invoked (XUL documents only).
 * @returns {Node} 
 * @static
 */
document.popupNode;

/**
 * Returns all the <script> elements on the document.
 * @returns {HTMLCollection} 
 * @static
 */
document.scripts;

/**
 * Returns a set of elements which have all the given class names. When called on the document object, the complete document is searched, including the root node. You may also call getElementsByClassName on any element; it will return only elements which are descendants of the specified root element with the given class names.
 * @syntax elements=document.getElementsByClassName(names);<br>elements=rootElement.getElementsByClassName(names);
 * @param {String} names names is a string representing the list of class names to match; class names are separated by whitespace
 * @returns {NodeList} elements is a live NodeList (but see the note below) of found elements in the order they appear in the tree.
 * @static
 */
document.getElementsByClassName = function() {};

/**
 * Gets/sets directionality (rtl/ltr) of the document
 * @returns {String} 
 * @static
 */
document.dir;

/**
 * Returns the currently focused element
 * @returns {Element} 
 * @static
 */
document.activeElement;

/**
 * Returns the HEAD node of the current document.
 * @returns {HTMLHeadElement} 
 * @static
 */
document.head;

/**
 * Returns the date on which the document was last modified.
 * @returns {String} 
 * @static
 */
document.lastModified;

/**
 * Gets/sets the background color of the current document.
 * @returns {String} 
 * @static
 */
document.characterSet;

/**
 * This method compiles an XPathExpression which can then be used for (repeated) evaluations.
 * @syntax xpathExpr=document.createExpression(xpathText,namespaceURLMapper);
 * @param {String} xpathText String xpathText (the XPath expression to be compiled)
 * @param {Function} namespaceURLMapper Function namespaceURLMapper (maps a namespace prefix to a namespace URL (or null if none needed))
 * @returns {String} 
 * @static
 */
document.createExpression = function() {};

/**
 * Returns loading status of the document
 * @returns {String} 
 * @static
 */
document.readyState;

/**
 * Returns the element from the document whose elementFromPoint method is being called which is the topmost element which lies under the given point.  To get an element, specify the point via coordinates, in CSS pixels, relative to the upper-left-most point in the window or frame containing the document.
 * @syntax varelement=document.elementFromPoint(x,y);
 * @param {Number} x x and y specify the coordinates to check, in CSS pixels relative to the upper-left corner of the document's containing window or frame.
 * @param {Number} y x and y specify the coordinates to check, in CSS pixels relative to the upper-left corner of the document's containing window or frame.
 * @returns {Element} element is an element object.
 * @static
 */
document.elementFromPoint = function() {};

/**
 * Allows web sites to register themselves as possible handlers for particular protocols.<br>Note: Web sites may only register protocol handlers for themselves. For security reasons, it's not possible for an extension or web site to register protocol handlers targeting other sites.
 * @returns {undefined} 
 * @static
 */
document.registerProtocolHandler = function() {};

/**
 * Used with document.load to indicate an asynchronous request.
 * @returns {undefined} 
 * @static
 */
document.async;

/**
 * Returns a new Range object. 
 * @syntax range=document.createRange();
 * @returns {Range} range is the created range object. 
 * @static
 */
document.createRange = function() {};

/**
 * Creates an event of the type specified. The returned object should be first initialized and can then be passed to element.dispatchEvent.
 * @syntax varevent=document.createEvent(type);
 * @param {String} type type is a string that represents the type of event to be created. Possible event types include "UIEvents", "MouseEvents", "MutationEvents", and "HTMLEvents". See Notes section for details.
 * @returns {Event} event is the created Event object.
 * @static
 */
document.createEvent = function() {};

/**
 * Reports whether or not the specified editor query command is supported by the browser.
 * @syntax varisSupported=document.queryCommandSupported(command);
 * @param {String} command     The command for which to determine support.
 * @returns {Boolean} 
 * @static
 */
document.queryCommandSupported = function() {};

/**
 * The DOM getSelection() method is available on the Window and Document interfaces. See window.getSelection()  for details.
 * @returns {Selection} 
 * @static
 */
document.getSelection = function() {};

/**
 * document.load() is a part of an old version of the W3C DOM Level 3 Load & Save module. Can be used with document.async to indicate whether the request is synchronous or asynchronous (the default). As of at least Gecko 1.9, this no longer supports cross-site loading of documents (Use XMLHttpRequest instead).
 * @returns {undefined} 
 * @static
 */
document.load = function() {};

/**
 * Returns a list of the stylesheet objects on the current document.
 * @returns {StyleSheetList} 
 * @static
 */
document.styleSheets;

/**
 * Returns a new TreeWalker object.
 * @syntax vartreeWalker=document.createTreeWalker(root,whatToShow,filter,entityReferenceExpansion);
 * @param {Node} root root is the root of the TreeWalker's traversal. Typically this will be an element owned by the document.
 * @param {Number} whatToShow whatToShow is a bitmask created by combining the constant properties of NodeFilter. It is a convenient way of filtering for certain types of node.
 * @param {Number} filter filter is an optional object with a method acceptNode, which is called by the TreeWalker to determine whether or not to accept a node that has passed the whatToShow check. The function should return NodeFilter.FILTER_ACCEPT, which causes the TreeWalker to return the node, NodeFilter.FILTER_REJECT, which causes the TreeWalker to ignore the entire subtree, or NodeFilter.FILTER_SKIP. Gecko allows filter to be a function instead of an object.
 * @param {String} entityReferenceExpansion entityReferenceExpansion is not used by Gecko but the value is saved and returned by the nsIDOMNodeIterator property.
 * @returns {TreeWalker} 
 * @static
 */
document.createTreeWalker = function() {};

/**
 * Represents the document prototype object.
 * @syntax document.prototype
 * @static
 */
document.prototype = new HTMLDocument();

